@@ -8,25 +8,25 @@ from .cmd import path_copy, docker_run, rmtree
 class Bundler(ABC):
     def __init__(
         self,
-        workdir: str = "/opt",
-        local_dir: str = "./layer",
+        workdir: str,
+        local_dir: Path,
         container_cmd: str = None,
         container: str = None,
         build_artifact: str = None,
         container_output_dir: str = None,
     ):
+        self._container = container
+        self._container_cmd = container_cmd
         self.__cleanup_paths: List[Path] = []
-        self.workdir = workdir
-        self.local_path = Path(local_dir)
-        self.build_artifact_path = Path(build_artifact) if build_artifact else None
-        self.prep_local(self.local_path, self.build_artifact_path)
-        self.container = container
-        self.container_cmd = container_cmd
-        self.container_output_dir = (
+        self.__workdir = workdir
+        self._local_path = Path(local_dir)
+        self.__build_artifact_path = Path(build_artifact) if build_artifact else None
+        self.__prep_local(self._local_path, self.__build_artifact_path)
+        self.__container_output_dir = (
             container_output_dir if container_output_dir else workdir
         )
 
-    def prep_local(self, local_path: Path, build_artifact_path: Optional[Path]):
+    def __prep_local(self, local_path: Path, build_artifact_path: Optional[Path]):
         local_path.mkdir(parents=True, exist_ok=True)
         if not build_artifact_path:
             return
@@ -39,43 +39,39 @@ class Bundler(ABC):
                 local_path.resolve()
             ):
                 path_copy(build_artifact_path, local_path)
-            self.build_artifact_path = local_path / build_artifact_path.name
+            self.__build_artifact_path = local_path / build_artifact_path.name
 
     def bundle(self) -> Path:
         try:
             self.pre_bundle()
             with logger().status("bundling layer with Docker..."):
-                cmd_str = f"{self.container_cmd} && zip -r layer.zip *"
-                if self.container_output_dir != self.workdir:
-                    cmd_str = f"mkdir -p {self.container_output_dir} && " + cmd_str
+                cmd_str = self._container_cmd
+                if self.__container_output_dir != self.__workdir:
+                    cmd_str = f"mkdir -p {self.__container_output_dir} && " + cmd_str
                 try:
                     logger().info(
-                        f"starting bundling task with docker container {self.container}"
+                        f"starting bundling task with docker container {self._container}"
                     )
                     docker_run(
-                        container=self.container,
-                        workdir=self.workdir,
-                        volume=f"{self.local_path.absolute()}:{self.container_output_dir}",
+                        container=self._container,
+                        workdir=self.__workdir,
+                        volume=f"{self._local_path.absolute()}:{self.__container_output_dir}",
                         container_cmd=["/bin/bash", "-c", cmd_str],
                     )
                 except Exception as e:
                     logger().fatal_error(
-                        f"failed bundling layer with docker container {self.container}: {str(e)}"
+                        f"failed bundling layer with docker container {self._container}: {str(e)}"
                     )
                 logger().success("bundling complete!")
             self.post_bundle()
-            # delete all files in the output dir that are not the layer itself
-            for p in self.local_path.iterdir():
-                if p.name != "layer.zip":
-                    self.add_cleanup_path(p)
         finally:
-            self.cleanup()
-        return self.local_path / "layer.zip"
+            self.__cleanup()
+        return self._local_path
 
     def add_cleanup_path(self, p: Path):
         self.__cleanup_paths.append(p)
 
-    def cleanup(self):
+    def __cleanup(self):
         with logger().status("cleaning up..."):
             for p in self.__cleanup_paths:
                 if p.is_dir():
