@@ -23,15 +23,15 @@ class PythonBundler(Bundler):
     def __init__(
         self,
         runtime: str,
-        local_dir: str = "./layer",
+        local_dir: Path,
         container: str = None,
         artifact_dir: str = None,
         packages: List[str] = None,
         manifest: str = None,
     ):
-        self.manifest = manifest
-        self.packages = packages
-        self.artifact_dir = Path(artifact_dir) if artifact_dir else None
+        self.__manifest = manifest
+        self.__packages = packages
+        self.__artifact_dir = Path(artifact_dir) if artifact_dir else None
 
         if not container:
             container = PYTHON_ECR_TEMPLATE.substitute(
@@ -39,6 +39,7 @@ class PythonBundler(Bundler):
             )
 
         super(PythonBundler, self).__init__(
+            workdir="/opt",
             container=container,
             container_cmd="",
             local_dir=local_dir,
@@ -47,19 +48,19 @@ class PythonBundler(Bundler):
 
     def pre_bundle(self):
         container_cmds = []
-        local_src = self.local_path / "src"
+        local_src = self._local_path / "src"
         try:
             local_src.mkdir(parents=True, exist_ok=True)
         except Exception as e:
             logger().fatal_error(f"failed to create directory {local_src} Error: {e}")
 
-        build_target = self.local_path / "python"
+        self.add_cleanup_path(local_src)
+        build_target = self._local_path / "python"
 
-        if self.artifact_dir and self.artifact_dir.exists():
-            package_src = local_src / self.artifact_dir.name
-            self.add_cleanup_path(local_src)
+        if self.__artifact_dir and self.__artifact_dir.exists():
+            package_src = local_src / self.__artifact_dir.name
             # copy to package source
-            path_copy(self.artifact_dir, package_src)
+            path_copy(self.__artifact_dir, package_src)
 
             if (package_src / "requirements.txt").is_file() or (
                 package_src / "setup.py"
@@ -74,15 +75,15 @@ class PythonBundler(Bundler):
                 # copy the contents of the dir straight to the build target
                 path_copy(package_src, build_target)
 
-        if self.packages or self.manifest:
+        if self.__packages or self.__manifest:
             cmd = "pip install -t python"
 
-            if self.manifest:
-                cmd += f" -r {Path(self.manifest).name}"
+            if self.__manifest:
+                cmd += f" -r {Path(self.__manifest).name}"
 
-            if self.packages:
-                cmd += " " + " ".join(self.packages)
+            if self.__packages:
+                cmd += " " + " ".join(self.__packages)
 
             container_cmds.append(cmd)
 
-        self.container_cmd = "; ".join(container_cmds)
+        self._container_cmd = "; ".join(container_cmds)
